<template>
  <div class="app-container">
    <el-form
      :model="queryParams"
      ref="queryForm"
      size="small"
      :inline="true"
      v-show="showSearch"
      label-width="68px"
    >
      <el-form-item label="项目名称" prop="proId">
        <el-input
          v-model="queryParams.proId"
          placeholder="请输入项目名称"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="性别分组" prop="tjSex">
        <el-select
          v-model="queryParams.tjSex"
          placeholder="请选择体检人性别"
          clearable
        >
          <el-option
            v-for="dict in dict.type.sys_user_sex"
            :key="dict.value"
            :label="dict.label"
            :value="dict.value"
          />
        </el-select>
      </el-form-item>
      <el-form-item label="其他分组" prop="tjType">
        <el-select
          v-model="queryParams.tjType"
          placeholder="请选择体检人类型"
          clearable
        >
          <el-option
            v-for="dict in dict.type.dict_personnel_type"
            :key="dict.value"
            :label="dict.label"
            :value="dict.value"
          />
        </el-select>
      </el-form-item>
      <el-form-item>
        <el-button
          type="primary"
          icon="el-icon-search"
          size="mini"
          @click="handleQuery"
          >搜索</el-button
        >
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery"
          >重置</el-button
        >
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['standard:standard:add']"
          >新增</el-button
        >
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['standard:standard:edit']"
          >修改</el-button
        >
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['standard:standard:remove']"
          >删除</el-button
        >
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          @click="handleExport"
          v-hasPermi="['standard:standard:export']"
          >导出</el-button
        >
      </el-col>
      <right-toolbar
        :showSearch.sync="showSearch"
        @queryTable="getList"
      ></right-toolbar>
    </el-row>

    <el-table border
      v-loading="loading"
      :data="standardList"
      @selection-change="handleSelectionChange"
    >
      <el-table-column type="selection" width="55" align="center" fixed="left" />
      <el-table-column label="序号" align="center" prop="newID"  />
      <el-table-column label="项目名称" align="center" prop="proName" />
      <el-table-column label="体检人性别" align="center" prop="tjSex">
        <template slot-scope="scope">
          <dict-tag
            :options="dict.type.sys_user_sex"
            :value="scope.row.tjSex"
          />
        </template>
      </el-table-column>
      <el-table-column label="体检人类型" align="center" prop="tjType">
        <template slot-scope="scope">
          <dict-tag
            :options="dict.type.dict_personnel_type"
            :value="scope.row.tjType"
          />
        </template>
      </el-table-column>
      <el-table-column
        label="标准最大值"
        align="center"
        prop="tjStandardGtValue"
      />
      <el-table-column
        label="标准最小值"
        align="center"
        prop="tjStandardLtValue"
      />
      <el-table-column label="单位" align="center" prop="company" />
      <el-table-column
        label="操作"
        align="center"
        fixed="right"
        class-name="small-padding fixed-width"
      >
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['standard:standard:edit']"
            title="修改"
            ></el-button
          >
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['standard:standard:remove']"
            title="删除"
            ></el-button
          >
        </template>
      </el-table-column>
    </el-table>

    <div class="pag">
      <pagination
      v-show="total > 0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />
    </div>
    

    <!-- 添加或修改standard对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="项目名称" prop="proName">
          <el-input v-model="form.proName" placeholder="请输入项目名称" />
        </el-form-item>
        <el-form-item label="性别" prop="tjSex">
          <el-select v-model="form.tjSex" placeholder="请选择体检人性别">
            <el-option
              v-for="dict in dict.type.sys_user_sex"
              :key="dict.value"
              :label="dict.label"
              :value="parseInt(dict.value)"
            ></el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="类型" prop="tjType">
          <el-select v-model="form.tjType" placeholder="请选择体检人类型">
            <el-option
              v-for="dict in dict.type.dict_personnel_type"
              :key="dict.value"
              :label="dict.label"
              :value="parseInt(dict.value)"
            ></el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="最大值" prop="tjStandardGtValue">
          <el-input
            v-model="form.tjStandardGtValue"
            placeholder="请输入标准最大值"
          />
        </el-form-item>
        <el-form-item label="最小值" prop="tjStandardLtValue">
          <el-input
            v-model="form.tjStandardLtValue"
            placeholder="请输入标准最小值"
          />
        </el-form-item>
        <el-form-item label="单位" prop="company">
          <el-input v-model="form.company" placeholder="请输入单位" />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import {
  listStandard,
  getStandard,
  delStandard,
  addStandard,
  updateStandard,
} from "@/api/standard/standard";

export default {
  name: "Standard",
  dicts: ["sys_user_sex", "dict_personnel_type"],
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // standard表格数据
      standardList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        proName: null,
        tjSex: null,
        tjType: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        proId: [
          { required: true, message: "", trigger: "blur" },
        ],
        createTime: [
          { required: true, message: "", trigger: "blur" },
        ],
      },
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询standard列表 */
    getList() {
      this.loading = true;
      listStandard(this.queryParams).then((response) => {
        response.rows.forEach((item, index) => 
        {item.newID =(this.queryParams.pageNum - 1) * this.queryParams.pageSize +index +1;
          });
        this.standardList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        proId: null,
        tjSex: null,
        tjType: null,
        tjStandardGtValue: null,
        tjStandardLtValue: null,
        company: null,
        createBy: null,
        createTime: null,
        updateBy: null,
        updateTime: null,
        deleted: null,
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map((item) => item.id);
      this.single = selection.length !== 1;
      this.multiple = !selection.length;
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "项目标准值信息维护";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      this.open = true;
      this.form = row;
      this.title = "项目标准值信息维护";
      // const id = row.id || this.ids;
      // getStandard(id).then((response) => {
      //   this.form = response.data;
      //   this.open = true;
      //   this.title = "修改standard";
      // });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate((valid) => {
        if (valid) {
          if (this.form.proId != null) {
            updateStandard(this.form).then((response) => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addStandard(this.form).then((response) => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal
        .confirm('是否确认删除standard编号为"' + ids + '"的数据项？')
        .then(function () {
          return delStandard(ids);
        })
        .then(() => {
          this.getList();
          this.$modal.msgSuccess("删除成功");
        })
        .catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download(
        "standard/standard/export",
        {
          ...this.queryParams,
        },
        `standard_${new Date().getTime()}.xlsx`
      );
    },
  },
};
</script>
<style scoped>
.pag{
  display: flex;
  justify-content: center;
}
</style>
